@@ -190,13 +190,13 @@ static void report_stat_differences(options *opts,
     unsigned long	diffs	 = 0;
     
     if ((flags & RULE_INODE)
-	&& (sa->st_ino != sa->st_ino))
+	&& (sa->st_ino != sb->st_ino))
       diffs	 |= RULE_INODE;
     if ((flags & RULE_PERMS)
 	&& (sa->st_mode != sb->st_mode))
       diffs	 |= RULE_PERMS;
     if ((flags & RULE_NLINK)
-	&& (sa->st_nlink != sa->st_nlink))
+	&& (sa->st_nlink != sb->st_nlink))
       diffs	 |= RULE_NLINK;
     if ((flags & RULE_UID)
 	&& (sa->st_uid != sb->st_uid))
