@@ -190,7 +190,8 @@ void hashtbl_resize(hashtbl_t *h, size_t capacity)
     uint32_t	hashval;
 
 #ifdef	DEBUG
-    printf("debug: resizing table: %d --> %d ... ", oldcapacity, capacity);
+    fprintf(stderr,
+	    "debug: resizing table: %d --> %d ... ", oldcapacity, capacity);
 #endif
     if (! (newtbl = malloc(sizeof(hashnode_t *) * capacity)) ) {
       pwarn("could not resize hash table");
