@@ -28,12 +28,35 @@ MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 #include	"options.h"
 #include	"elcerror.h"
 #include	"missing.h"
+#include	"xml.h"
 #include	"missing_p.h"
 #include	"elcerror_p.h"
+#include	"xml_p.h"
 #ifdef		ELC_FIND_LEAKS
 #include	"leakfind.h"
 #endif
 
+static void print_missing_xml(FILE *out, options *opts,
+			      const char *key, size_t klen)
+{
+    XML_START_PRINT(out, "missing");
+
+    for (; klen--; ++key)
+      xml_putc(out, *key);
+
+    XML_END_PRINT(out, "missing");
+    putc('\n', out);
+}
+
+static void print_missing_abbrev(FILE *out, options *opts,
+			      const char *key, size_t klen)
+{
+    fputs("missing: ", stdout);
+    while (klen--)
+      putchar(*key++);
+    putchar('\n');
+}
+
 static void do_currdb_check(options *opts, struct cdb *curr_cdb,
 			    char *key, size_t klen)
 {
@@ -44,10 +67,10 @@ static void do_currdb_check(options *opts, struct cdb *curr_cdb,
 	  "Error: looking up file (%s) in current-state database (%s): %s",
 	  key, opts->currdbname, strerror(errno));
     else if (! ret) {
-      fputs("missing: ", stdout);
-      while (klen--)
-	putchar(*key++);
-      putchar('\n');
+      if (opts->output == OUTPUT_XML)
+	print_missing_xml(stdout, opts, key, klen);
+      else
+	print_missing_abbrev(stdout, opts, key, klen);
     }
 }
 
@@ -76,8 +99,10 @@ void check_for_missing(options *opts)
 
     open_current_state_cdb(opts->currdbname, &curr_cdb);
 
-    if (opts->verbose > 0)
+    if ((opts->verbose > 0)
+	&& (opts->output != OUTPUT_XML))
       puts(PROGNAME ": checking for missing files --------------");
+
     knownseq.fd	 = opts->knowndb.fd;
     if (cdb_seq_start(&knownseq) == -1)
       DIE("cdb_seq_start");
